function [D,dD]=arrayresp(theta,pos,fs,T,del)

% D=arrayresp(theta,pos,fs,T,del) returns array responce vectors for angles
% in theta at various frequencies. The vectors are returnd in D [TT, Dx,
% Da], where TT=T/2+1 represent the frequency bins up to the Nyquist
% frequency, Da=length(theta) the number of anlges, and Dx=lenght(pos) the
% number of microphones. The sampling frequency is given in fs and T
% corresponds to the size of the FFT with which this responce vectors would
% be used. The array responce for a FIR filter matrix W is given as,
% R(i,:,:)=W(i,:,:)*D(i,:,:), for every frequency bin i. The responce
% contains an overall delay of del.

% Lucas Parra, Aug 31 2000
%              Sep 21 2000 included delay

% Ref: Barry Van Veen, Kevin Buckley, "Beam forming techniques for spacial
% filtering", IEEE Signal Processing Magazine.

if nargin<5, del=0; end

csound=342; % speed of sound in air
TT = T/2+1;
theta = theta(:)'*pi/180; % make user its a row and conver into rad
pos = pos(:);             % make user its a column
tau_theta = sqrt(-1) * 2 * pi * pos*sin(theta)/csound;
freq = (0:TT-1)'*fs/T;
D = exp(reshape(kron(tau_theta,freq),[length(freq) size(tau_theta)]));

if del
  shift(1+del)=1; shift=conj(fft(shift',T)); 
  shift=repmat(shift(1:TT),[1 length(pos) length(theta)]);
  D = D.*shift;
end

if nargout==2,
  tau_theta = sqrt(-1) * 2 * pi * pos*cos(theta)/csound;
  dD = D.*reshape(kron(tau_theta,freq),[length(freq) size(tau_theta)]);
  if del, dD = dD.*shift;  end
end