% basis transform parameters
nPbasis =0.03;    % noise power for basis computation 
nPbasis =0.001;    % noise power for basis computation 
nPdesign=0.0001;  % noise power for design of optimal coefficients 
M=20;              % number of Legedre basis vectors
fs = 10000;       % sampling rate
T=128;          % filter length
beta = 0;         % steering angle
pos_error = 0.001; % std of position error (normaly distributed)

% beam design parameters
invar=1; % choose opt. coeff. for desired response equal for all freq.
pos = 0.01*[0, 2, 5, 7, 10]'; % microphone position in meters
theta_test = [-80 -65 -50 -40 -5 0 5 40 50 65 80];
y_test =     [1 1 1 1 0 0 0 1 1 1 1];

%filename='maximum'; y_test = 1-y_test; 
filename='minimum'; y_test = y_test;   

figure(1) % display desired response
subplot(2,2,2)
stem(theta_test,y_test); ylim([-0.5 1.5]); xlim([-90 90])
title('desired response'); xlabel('angle (deg)')
colormap gray

figure(2) % basic simulation
finvariant(pos,T,fs,M,nPbasis,nPdesign,theta_test,y_test,invar,beta,0);
colormap gray

figure(3) % modify noise term for basis
finvariant(pos,T,fs,M,0,nPdesign,theta_test,y_test,invar,beta,0);
colormap gray

figure(4) % 'naive' basis
finvariant(pos,T,fs,0,nPbasis,nPdesign,theta_test,y_test,invar,beta,0);
colormap gray

figure(5) % steering
finvariant(pos,T,fs,M,nPbasis,nPdesign,theta_test,y_test,invar,-30,0);
colormap gray

figure(6) % number of microphones
finvariant(0.01*[0, 5, 10]',T,fs,M,nPbasis,nPdesign,theta_test,y_test,invar,beta,0);
colormap gray

% save all figures as eps
for i=1:gcf,  saveas(i,[filename num2str(i)],'epsc'); end;

figure(7) % show the basis rotation D
legshift(30/180*pi,20,1);
colormap gray
saveas(i,'legshift','eps');

figure(8) % basic simulation repeated but the response is displayed with
          % sensors moved from location by some small position error
W=finvariant(pos,T,fs,M,nPbasis,nPdesign,theta_test,y_test,invar,beta,0);
colormap gray, ca=caxis;
subplot(2,2,2)
polarresponce(W,[],pos'+pos_error*randn(size(pos')),fs);
title('Array Response')
caxis(ca);
h=colorbar('vert'); set(get(h,'title'),'string','dB')
