function [P,Y] = legdecomp(x,N,y)
  
% P = legdecomp(x,N) Computes the Legendre polynomial up to order N for
% values x.
%
% [P,Y] = legdecomp(x,N,y) also evaluates the corresponding decomposition
% coefficients Y of the function y=f(x) so that y_est = P'*Y approximates
% y. y may be a column vector or a matrix and must have the same number of
% rows as x. The decomposition is computed for each column in the matrix.
%
%
% Example:
%
%  x=[-1:0.001:1]'; y=sign(x);
% [P,Y] = legdecomp(x,10,y); plot(x,[y P*Y]);
%
% see legendre()

% (c) Lucas C. Parra, March 21, 2005
% (c) Lucas C. Parra, August 9, 2005,
%                     Feb 28, 2006, explicit inversion with pinv()  


x=x(:)';
for n=1:N+1
  p = legendre(n-1,x);
  P(:,n) = p(1,:)';
end

if nargin>2
  % explicit quatratue computation
  %  W = mean([diff(x) 0;0 diff(x)])';
  %  N = diag((2*(0:N)+1)/2);
  %  Y = N*P'*(repmat(W,[1 size(y,2)]).*y);
  % more efficient and more accurate inverse
  Y = pinv(P)*y;
end
