function D=legshift(beta,N,show) 

% D=legshift(beta,N,show) Generates a shift matrix that approximately
% tranforms Legendre coefficients of a function to the coefficients of the
% same function shifted by angle beta (in radians). N is the order of the
% Lengendre baisis. For example:
%
% N=20; x=[-1:0.001:1]'; y=sign(x);
% [P,Y] = legdecomp(x,N,y); 
% D=legshift(pi/4,N);
% plot(acos(x),[y P*Y P*D'*Y]);
% 
% see legdecomp().

% (c) Lucas C. Parra, August 12, 2005
%                     Feb 26, 2005, Equidistant sampling in theta

equi_theta=1;     % equidistant sampling in theta vs cos(theta) 

if nargin<3, show=0; end

if equi_theta
  theta=[-pi/2:pi/2*0.001:pi/2]'; 
  x = sin(theta);
  xb= sin(theta+beta);
else
  x=[-1:0.0001:1]';
  xb = x*cos(beta) + sin(acos(x))*sin(beta);
end

Pb = legdecomp(xb,N);

[P,D] = legdecomp(x,N,Pb);
D=D';

if show
  Pt = P*D';
  bstr =  [num2str(beta/pi*180,2) '^o'];
  ca = [-1 1];
  subplot(2,2,4); imagesc(D); caxis(ca); colorbar; 
  title(['D_{ll''}(' bstr  ')']); xlabel('l'''); ylabel('l')
  subplot(2,2,1); imagesc(acos(x)/pi*180,0:N,P'); 
  title('P_l(cos(\vartheta))');  ylabel('l'); xlabel('\vartheta (deg)');
  subplot(2,2,2); imagesc(acos(x)/pi*180,0:N,Pb'); caxis(ca);
  title(['P_{l''}(cos(\vartheta-' bstr '))']); ylabel('l'''); xlabel('\vartheta (deg)');
  subplot(2,2,3); imagesc(acos(x)/pi*180,0:N,Pt'-Pb'); caxis(ca);
  title('Approximation error'); 
  xlabel('\vartheta (deg)'); ylabel('l'''); 
end