function [r,freq,theta] = polarresponce(W, w, pos, fs);

% polarresponce(W, w, pos, fs) shows the polar frequency responces in the
% far field of multidimensional FIR filters W [T D N] for floor(T/2+1)
% frequencies between 0 and the Nyquist frequency fs/2 for angles theta =
% -90..90 degree. T is the number of taps in the filters, D the number of
% output channels, N the number of inputs to W. It is assumed that the M
% microphones are omni-directional located at pos [1 M] and that the signals
% are weighted with coefficients w [N M] before filtering.
%
% [r,freq,theta] = polarresponce(W, w, pos, fs); will not show the
% responce but just return them in r [181, floor(T/2+1), D]. Note that r
% is complex valued representing the phase and amplitude responce.
%
% By default the sampling frequency is assumed fs=16 kHz, the spacing
% between the microphones 10 cm and no weighting is applied, i.e. N=M.
%
% see bfpolar()

% Lucas Parra, July 25 2000
% modified August 2005

% dimensions
[T,D,N] = size(W);
TT = floor(T/2+1);

% defaults
if nargin < 2 | isempty(w),   w  = eye(N); end
if nargin < 3 | isempty(pos), pos = 0.1*(0:size(w,2)-1); end
if nargin < 4 | isempty(fs),  fs = 16000; end;

% compute delay to each microphone as function of angle
theta = (-90:90)*pi/180;
csound=342;
tau_theta = sqrt(-1) * 2 * pi * pos'*sin(theta)/csound;

% get frequency components
Wfft = fft(W); Wfft = Wfft(1:TT,:,:);


% compute beam patern - unintelligible code but fast.
freq = (0:TT-1)'*fs/T;
d = exp(reshape(kron(tau_theta,freq),[length(freq) size(tau_theta)]));
w = repmat(shiftdim(w,-1),[length(freq) 1 1]);
r = ip(Wfft,ip(w,d));
r = permute(r,[1 3 2]);
  
% convert into degrees
theta = theta/pi*180;

% do some display
if nargout==0, 
  for i=1:D; 
    if D>1, subplot(1,D,i); end
    rdb = db(abs(squeeze(r(:,:,i))).^2+eps);
    f=find(mean(rdb,2)>-100);
    imagesc(theta,freq(f),rdb(f,:)); 
    axis('xy');
    xlabel('angle (deg)');
    ylabel('Hz');
  end; 
end;


return 

% compute beam patern - this is actually understandable matlab
df=1
for fi=0:df:T/2
  i=fi/df+1;
  freq(i) = fi*fs/T;
  r(i,:,:) =  (squeeze(Wfft(fi+1,:,:)) * w * exp(freq(i) * tau_theta))';
end






